<?php
/**
 * Multipurpose Corporate Theme Customizer
 *
 * @package Multipurpose Corporate
 */

/**
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function multipurpose_corporate_customize_register( $wp_customize ) {	

	//add home page setting pannel
	$wp_customize->add_panel( 'multipurpose_corporate_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'LT Settings', 'multipurpose-corporate' ),
	    'description' => __( 'Description of what this panel does.', 'multipurpose-corporate' ),
	) );

	$wp_customize->add_section( 'multipurpose_corporate_left_right' , array(
    	'title'      => __( 'General Settings', 'multipurpose-corporate' ),
		'priority'   => null,
		'panel' => 'multipurpose_corporate_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('multipurpose_corporate_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'multipurpose_corporate_sanitize_choices'	        
	));
	$wp_customize->add_control('multipurpose_corporate_theme_options',array(
        'type' => 'radio',
        'description' => __( 'Choose sidebar between different options', 'multipurpose-corporate' ),
        'label' => __( 'Do you want this section', 'multipurpose-corporate' ),
        'section' => 'multipurpose_corporate_left_right',
        'choices' => array(
            'One Column' => __('One Column ','multipurpose-corporate'),
            'Three Columns' => __('Three Columns','multipurpose-corporate'),
            'Four Columns' => __('Four Columns','multipurpose-corporate'),
            'Right Sidebar' => __('Right Sidebar','multipurpose-corporate'),
            'Left Sidebar' => __('Left Sidebar','multipurpose-corporate'),
            'Grid Layout' => __('Grid Layout','multipurpose-corporate')
        ),
	));

	//Topbar section
	$wp_customize->add_section('multipurpose_corporate_topbar',array(
		'title'	=> __('Topbar','multipurpose-corporate'),
		'description'	=> __('Add Topbar Content here','multipurpose-corporate'),
		'priority'	=> null,
		'panel' => 'multipurpose_corporate_panel_id',
	));

	$wp_customize->add_setting( 'multipurpose_corporate_sticky_header',array(
		'default'	=> false,
      	'sanitize_callback'	=> 'multipurpose_corporate_sanitize_checkbox'
    ) );
    $wp_customize->add_control('multipurpose_corporate_sticky_header',array(
    	'type' => 'checkbox',
    	'description' => __( 'Click on the checkbox to enable sticky header.', 'multipurpose-corporate' ),
        'label' => __( 'Sticky Header','multipurpose-corporate' ),
        'section' => 'multipurpose_corporate_topbar'
    ));

    //Show /Hide Topbar
	$wp_customize->add_setting( 'multipurpose_corporate_show_topbar',array(
		'default' => false,
      	'sanitize_callback'	=> 'multipurpose_corporate_sanitize_checkbox'
    ) );
    $wp_customize->add_control('multipurpose_corporate_show_topbar',array(
    	'type' => 'checkbox',
    	'description' => __( 'Click on the checkbox to enable Topbar.', 'multipurpose-corporate' ),
        'label' => __( 'Topbar','multipurpose-corporate' ),
        'section' => 'multipurpose_corporate_topbar'
    ));

	$wp_customize->add_setting('multipurpose_corporate_timming',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('multipurpose_corporate_timming',array(
		'label'	=> __('Add Timmings','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_topbar',
		'setting'	=> 'multipurpose_corporate_timming',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('multipurpose_corporate_call',array(
		'default'	=> '',
		'sanitize_callback'	=> 'multipurpose_corporate_sanitize_phone_number'
	));
	$wp_customize->add_control('multipurpose_corporate_call',array(
		'label'	=> __('Add Phone Number','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_topbar',
		'setting'	=> 'multipurpose_corporate_call',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('multipurpose_corporate_mail',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('multipurpose_corporate_mail',array(
		'label'	=> __('Add Email','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_topbar',
		'setting'	=> 'multipurpose_corporate_mail',
		'type'		=> 'text'
	));	

	$wp_customize->add_setting('multipurpose_corporate_button_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('multipurpose_corporate_button_text',array(
		'label'	=> __('Button text','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_topbar',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('multipurpose_corporate_button_link',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('multipurpose_corporate_button_link',array(
		'label'	=> __('Add Button Link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_topbar',
		'setting'	=> 'multipurpose_corporate_button_link',
		'type'		=> 'url'
	));

	//Social Icons(topbar)
	$wp_customize->add_section('multipurpose_corporate_social_media',array(
		'title'	=> __('Social Media','multipurpose-corporate'),
		'description'	=> __('Add Social Media Url here','multipurpose-corporate'),
		'priority'	=> null,
		'panel' => 'multipurpose_corporate_panel_id',
	));

	$wp_customize->add_setting('multipurpose_corporate_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('multipurpose_corporate_facebook_url',array(
		'label'	=> __('Add Facebook link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_social_media',
		'setting'	=> 'multipurpose_corporate_facebook_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('multipurpose_corporate_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('multipurpose_corporate_twitter_url',array(
		'label'	=> __('Add Twitter link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_social_media',
		'setting'	=> 'multipurpose_corporate_twitter_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('multipurpose_corporate_instagram_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('multipurpose_corporate_instagram_url',array(
		'label'	=> __('Add Instagram link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_social_media',
		'setting'	=> 'multipurpose_corporate_instagram_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('multipurpose_corporate_youtube_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('multipurpose_corporate_youtube_url',array(
		'label'	=> __('Add Youtube link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_social_media',
		'setting'	=> 'multipurpose_corporate_youtube_url',
		'type'		=> 'url'
	));

	$wp_customize->add_setting('multipurpose_corporate_pint_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('multipurpose_corporate_pint_url',array(
		'label'	=> __('Add Pinterest link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_social_media',
		'setting'	=> 'multipurpose_corporate_pint_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('multipurpose_corporate_linkedin_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('multipurpose_corporate_linkedin_url',array(
		'label'	=> __('Add LinkedIn link','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_social_media',
		'setting'	=> 'multipurpose_corporate_linkedin_url',
		'type'	=> 'url'
	));

	//home page slider
	$wp_customize->add_section( 'multipurpose_corporate_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'multipurpose-corporate' ),
		'priority'   => null,
		'panel' => 'multipurpose_corporate_panel_id'
	) );

	$wp_customize->add_setting('multipurpose_corporate_slider_hide',array(
       'default' => false,
       'sanitize_callback'  => 'multipurpose_corporate_sanitize_checkbox'
    ));
    $wp_customize->add_control('multipurpose_corporate_slider_hide',array(
       'type' => 'checkbox',
       'description' => __( 'Click on the checkbox to enable slider.', 'multipurpose-corporate' ),
       'label' => __('Show / Hide slider','multipurpose-corporate'),
       'section' => 'multipurpose_corporate_slidersettings',
    ));

	for ( $count = 1; $count <= 4; $count++ ) {
		// Add color scheme setting and control.
		$wp_customize->add_setting( 'multipurpose_corporate_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'multipurpose_corporate_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'multipurpose_corporate_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'multipurpose-corporate' ),
			'section'  => 'multipurpose_corporate_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//OUR services
	$wp_customize->add_section('multipurpose_corporate_services_section',array(
		'title'	=> __('Our Services','multipurpose-corporate'),
		'description'=> __('Select services pages.','multipurpose-corporate'),
		'panel' => 'multipurpose_corporate_panel_id',
	));	

	for ( $count = 0; $count <= 2; $count++ ) {
		$wp_customize->add_setting( 'multipurpose_corporate_services_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'multipurpose_corporate_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'multipurpose_corporate_services_page' . $count, array(
			'label'    => __( 'Select Service Page', 'multipurpose-corporate' ),
			'section'  => 'multipurpose_corporate_services_section',
			'type'     => 'dropdown-pages'
		));
	}

	//About
	$wp_customize->add_section('multipurpose_corporate_about_section',array(
		'title'	=> __('About us','multipurpose-corporate'),
		'description'=> __('Select the about us page.','multipurpose-corporate'),
		'panel' => 'multipurpose_corporate_panel_id',
	));	

	$wp_customize->add_setting( 'multipurpose_corporate_about_page' , array(
		'default'           => '',
		'sanitize_callback' => 'multipurpose_corporate_sanitize_dropdown_pages'
	));
	$wp_customize->add_control( 'multipurpose_corporate_about_page' , array(
		'label'    => __( 'Select About Page', 'multipurpose-corporate' ),
		'section'  => 'multipurpose_corporate_about_section',
		'type'     => 'dropdown-pages'
	));

	//footer
	$wp_customize->add_section('multipurpose_corporate_footer_section',array(
		'title'	=> __('Footer Text','multipurpose-corporate'),
		'description'	=> __('Add some text for footer like copyright etc.','multipurpose-corporate'),
		'panel' => 'multipurpose_corporate_panel_id'
	));
	
	$wp_customize->add_setting('multipurpose_corporate_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('multipurpose_corporate_footer_copy',array(
		'label'	=> __('Copyright Text','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_footer_section',
		'type'		=> 'text'
	));

	//Wocommerce Shop Page
	$wp_customize->add_section('multipurpose_corporate_woocommerce_shop_page',array(
		'title'	=> __('Woocommerce Shop Page','multipurpose-corporate'),
		'panel' => 'multipurpose_corporate_panel_id'
	));

	$wp_customize->add_setting( 'multipurpose_corporate_products_per_column' , array(
		'default'           => 3,
		'transport'         => 'refresh',
		'sanitize_callback' => 'multipurpose_corporate_sanitize_choices',
	) );
	$wp_customize->add_control( 'multipurpose_corporate_products_per_column', array(
		'label'    => __( 'Product Per Columns', 'multipurpose-corporate' ),
		'description'	=> __('How many products should be shown per Column?','multipurpose-corporate'),
		'section'  => 'multipurpose_corporate_woocommerce_shop_page',
		'type'     => 'select',
		'choices'  => array(
			'2' => '2',
			'3' => '3',
			'4' => '4',
			'5' => '5',
		),
	)  );

	$wp_customize->add_setting('multipurpose_corporate_products_per_page',array(
		'default'	=> 9,
		'sanitize_callback'	=> 'multipurpose_corporate_sanitize_float',
	));	
	$wp_customize->add_control('multipurpose_corporate_products_per_page',array(
		'label'	=> __('Product Per Page','multipurpose-corporate'),
		'description'	=> __('How many products should be shown per page?','multipurpose-corporate'),
		'section'	=> 'multipurpose_corporate_woocommerce_shop_page',
		'type'		=> 'number'
	));

	// logo site title
	$wp_customize->add_setting('multipurpose_corporate_site_title_tagline',array(
       'default' => true,
       'sanitize_callback'	=> 'multipurpose_corporate_sanitize_checkbox'
    ));
    $wp_customize->add_control('multipurpose_corporate_site_title_tagline',array(
       'type' => 'checkbox',
       'label' => __('Display Site Title and Tagline in Header','multipurpose-corporate'),
       'section' => 'title_tagline'
    ));
	
}
add_action( 'customize_register', 'multipurpose_corporate_customize_register' );	

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Multipurpose_Corporate_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Multipurpose_Corporate_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Multipurpose_Corporate_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority' => 9,
					'title'    => esc_html__( 'Corporate Pro', 'multipurpose-corporate' ),
					'pro_text' => esc_html__( 'Go Pro', 'multipurpose-corporate' ),
					'pro_url'  => esc_url( 'https://www.logicalthemes.com/themes/premium-corporate-wordpress-theme/' ),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'multipurpose-corporate-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'multipurpose-corporate-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Multipurpose_Corporate_Customize::get_instance();